==> v1.0.0.tar.gz: dchat/bot/src/main/java/de/hhhammer/dchat/bot/discord/MessageCreateHandler.java <==
package de.hhhammer.dchat.bot.discord;

import de.hhhammer.dchat.bot.openai.ResponseException;
import org.javacord.api.entity.message.MessageType;
import org.javacord.api.event.message.MessageCreateEvent;
import org.javacord.api.listener.message.MessageCreateListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;

public class MessageCreateHandler implements MessageCreateListener {
    private static final Logger logger = LoggerFactory.getLogger(MessageCreateHandler.class);

    private final MessageHandler messageHandler;

    public MessageCreateHandler(MessageHandler messageHandler) {
        this.messageHandler = messageHandler;
    }

    @Override
    public void onMessageCreate(MessageCreateEvent event) {
        Thread.ofVirtual().start(() -> {
            if (!event.canYouReadContent() || event.getMessageAuthor().isBotUser() || !(event.getMessage().getType() == MessageType.NORMAL || event.getMessage().getType() == MessageType.REPLY)) {
                return;
            }
            if (!this.messageHandler.canHandle(event)) {
                return;
            }
            if (!this.messageHandler.isAllowed(event)) {
                return;
            }
            if (this.messageHandler.exceedsRate(event)) {
                event.getChannel().sendMessage("Rate limit hit - cooling down...");
                return;
            }
            try {
                this.messageHandler.handle(event);
            } catch (ResponseException | IOException | InterruptedException e) {
                logger.error("Reading a message from the listener", e);
                event.getMessage().reply("Sorry but something went wrong :(");
            }
        });
    }
}

==> v1.0.2.tar.gz: dchat/bot/src/main/java/de/hhhammer/dchat/bot/discord/MessageCreateHandler.java <==
package de.hhhammer.dchat.bot.discord;

import de.hhhammer.dchat.bot.openai.ResponseException;
import org.javacord.api.entity.message.MessageType;
import org.javacord.api.event.message.MessageCreateEvent;
import org.javacord.api.listener.message.MessageCreateListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;

public class MessageCreateHandler implements MessageCreateListener {
    private static final Logger logger = LoggerFactory.getLogger(MessageCreateHandler.class);

    private final MessageHandler messageHandler;

    public MessageCreateHandler(MessageHandler messageHandler) {
        this.messageHandler = messageHandler;
    }

    @Override
    public void onMessageCreate(MessageCreateEvent event) {
        Thread.ofVirtual().start(() -> {
            if (!event.canYouReadContent() || event.getMessageAuthor().isBotUser() || !isNormalOrReplyMessageType(event)) {
                return;
            }
            if (!this.messageHandler.canHandle(event)) {
                return;
            }
            if (!this.messageHandler.isAllowed(event)) {
                return;
            }
            if (this.messageHandler.exceedsRate(event)) {
                event.getChannel().sendMessage("Rate limit hit - cooling down...");
                return;
            }
            try {
                this.messageHandler.handle(event);
            } catch (ResponseException | IOException | InterruptedException e) {
                logger.error("Reading a message from the listener", e);
                event.getMessage().reply("Sorry but something went wrong :(");
            }
        });
    }

    private boolean isNormalOrReplyMessageType(MessageCreateEvent event) {
        MessageType type = event.getMessage().getType();
        return type == MessageType.NORMAL || type == MessageType.REPLY;
    }
}
